@@ -20,7 +20,9 @@ describe 'cinder::policy' do
         :key   => 'context_is_admin',
         :value => 'foo:bar'
       })
-      is_expected.to contain_cinder_config('oslo_policy/policy_file').with_value('/etc/cinder/policy.json')
+      is_expected.to contain_oslo__policy('cinder_config').with(
+        :policy_file => '/etc/cinder/policy.json',
+      )
     end
   end
 
@@ -29,7 +31,7 @@ describe 'cinder::policy' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge(OSDefaults.get_facts({:processorcount => 8}))
+        facts.merge!(OSDefaults.get_facts())
       end
 
       it_configures 'cinder policies'
